@@ -35,7 +35,7 @@
 #include "skgtransactionmng.h"
 
 SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
-    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Advices")), m_maxAdvice(7), m_refreshNeeded(true), m_refresh(NULL)
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Advices")), m_maxAdvice(7), m_refreshNeeded(true), m_refresh(NULL), m_inapplyall(false)
 {
     SKGTRACEINFUNC(10);
 
@@ -131,7 +131,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 {
     SKGTRACEINFUNC(10);
     SKGTabPage* page = SKGTabPage::parentTabPage(this);
-    if (!iForce && ((page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) || !m_menuAuto->isChecked())) {
+    if (m_inapplyall || (!iForce && ((page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) || !m_menuAuto->isChecked()))) {
         m_refreshNeeded = true;
         if (m_refresh) {
             m_refresh->show();
@@ -168,6 +168,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     // Fill layout
     int nbDisplayedAdvice = 0;
     int nb = globalAdviceList.count();
+    m_recommendedActions.clear();
     for (int i = 0; i < m_maxAdvice && i < nb; ++i) {
         // Get advice
         SKGAdvice ad = globalAdviceList.at(i);
@@ -178,34 +179,34 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
         // Add ignored action
         QList<SKGAdvice::SKGAdviceAction> autoCorrections = ad.getAutoCorrections();
-	{
-	  SKGAdvice::SKGAdviceAction dismiss;
-	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss");
-	  dismiss.IconName="edit-delete";
-	  dismiss.IsRecommended=false;
-	  autoCorrections.push_back(dismiss);
-	}
-	{
-	  SKGAdvice::SKGAdviceAction dismiss;
-	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss during current month");
-	  dismiss.IconName="edit-delete";
-	  dismiss.IsRecommended=false;
-	  autoCorrections.push_back(dismiss);
-	}
-	{
-	  SKGAdvice::SKGAdviceAction dismiss;
-	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss this kind");
-	  dismiss.IconName="edit-delete";
-	  dismiss.IsRecommended=false;
-	  autoCorrections.push_back(dismiss);
-	}
-	{
-	  SKGAdvice::SKGAdviceAction dismiss;
-	  dismiss.Title=i18nc("Dismiss an advice provided", "Dismiss this kind during current month");
-	  dismiss.IconName="edit-delete";
-	  dismiss.IsRecommended=false;
-	  autoCorrections.push_back(dismiss);
-	}	
+        {
+            SKGAdvice::SKGAdviceAction dismiss;
+            dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss");
+            dismiss.IconName = "edit-delete";
+            dismiss.IsRecommended = false;
+            autoCorrections.push_back(dismiss);
+        }
+        {
+            SKGAdvice::SKGAdviceAction dismiss;
+            dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss during current month");
+            dismiss.IconName = "edit-delete";
+            dismiss.IsRecommended = false;
+            autoCorrections.push_back(dismiss);
+        }
+        {
+            SKGAdvice::SKGAdviceAction dismiss;
+            dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss this kind");
+            dismiss.IconName = "edit-delete";
+            dismiss.IsRecommended = false;
+            autoCorrections.push_back(dismiss);
+        }
+        {
+            SKGAdvice::SKGAdviceAction dismiss;
+            dismiss.Title = i18nc("Dismiss an advice provided", "Dismiss this kind during current month");
+            dismiss.IconName = "edit-delete";
+            dismiss.IsRecommended = false;
+            autoCorrections.push_back(dismiss);
+        }
 
         int nbSolution = autoCorrections.count();
 
@@ -223,10 +224,10 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         KMenu* menu = new KMenu(this);
         menu->setIcon(icon->icon());
         for (int k = 0; k < nbSolution; ++k) {
-	    SKGAdvice::SKGAdviceAction adviceAction=autoCorrections.at(k);
+            SKGAdvice::SKGAdviceAction adviceAction = autoCorrections.at(k);
             QString actionText = adviceAction.Title;
             QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove("skg://"), false);
-	    QAction* act;
+            QAction* act;
             if (action) {
                 // This is an action
                 act = menu->addAction(action->icon(), action->text(), SKGMainPanel::getMainPanel(), SLOT(openPage()));
@@ -239,10 +240,12 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
                     act->setProperty("solution", k < nbSolution - 4 ? k : k - nbSolution);
                 }
             }
-            
-            if(act && adviceAction.IsRecommended) {
-	      act->setText(act->text() % i18nc("To recommend this action", " (recommended)"));
-	    }
+
+            if (act && adviceAction.IsRecommended) {
+                act->setToolTip(act->text());
+                act->setText(act->text() % i18nc("To recommend this action", " (recommended)"));
+                m_recommendedActions.append(act);
+            }
         }
 
         icon->setMenu(menu);
@@ -261,6 +264,26 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         ++nbDisplayedAdvice;
     }
 
+    // Add apply all recommended actions
+    QPushButton*  apply = NULL;
+    if (m_recommendedActions.count()) {
+        apply = new QPushButton(this);
+        apply->setIcon(KIcon("games-solve"));
+        apply->setIconSize(QSize(22, 22));
+        apply->setMaximumSize(QSize(22, 22));
+        apply->setCursor(Qt::PointingHandCursor);
+        QString ToolTip;
+        int nb = m_recommendedActions.count();
+        for (int i = 0; i < nb; ++i) {
+            if (i > 0) {
+                ToolTip += '\n';
+            }
+            ToolTip += m_recommendedActions[i]->toolTip();
+        }
+        apply->setToolTip(ToolTip);
+        connect(apply, SIGNAL(clicked(bool)), this, SLOT(applyRecommended()), Qt::QueuedConnection);
+    }
+
     // Add more
     if (nb > m_maxAdvice) {
         QPushButton*  more = new QPushButton(this);
@@ -268,9 +291,15 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         more->setIconSize(QSize(22, 22));
         more->setMaximumSize(QSize(22, 22));
         more->setCursor(Qt::PointingHandCursor);
+        more->setToolTip(i18nc("Information message", "Display all advices"));
         connect(more, SIGNAL(clicked(bool)), this, SLOT(moreAdvice()), Qt::QueuedConnection);
 
-        m_layout->addRow(more, new QLabel(this));
+        if (apply) {
+            m_layout->addRow(more, apply);
+            apply = NULL;
+        } else {
+            m_layout->addRow(more, new QLabel(this));
+        }
     } else if (nbDisplayedAdvice > 7) {
         // Add less
         QPushButton*  less = new QPushButton(this);
@@ -278,9 +307,18 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         less->setIconSize(QSize(22, 22));
         less->setMaximumSize(QSize(22, 22));
         less->setCursor(Qt::PointingHandCursor);
+        less->setToolTip(i18nc("Information message", "Display less advices"));
         connect(less, SIGNAL(clicked(bool)), this, SLOT(lessAdvice()), Qt::QueuedConnection);
+        if (apply) {
+            m_layout->addRow(less, apply);
+            apply = NULL;
+        } else {
+            m_layout->addRow(less, new QLabel(this));
+        }
+    }
 
-        m_layout->addRow(less, new QLabel(this));
+    if (apply) {
+        m_layout->addRow(apply, new QLabel(this));
     }
 
     // Add manual refresh button
@@ -289,6 +327,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     m_refresh->setIconSize(QSize(22, 22));
     m_refresh->setMaximumSize(QSize(22, 22));
     m_refresh->setCursor(Qt::PointingHandCursor);
+    m_refresh->setToolTip(i18nc("Information message", "Refresh advices"));
     m_refresh->hide();
     connect(m_refresh, SIGNAL(clicked(bool)), this, SLOT(dataModifiedForce()), Qt::QueuedConnection);
 
@@ -309,6 +348,16 @@ void SKGAdviceBoardWidget::lessAdvice()
     dataModifiedForce();
 }
 
+void SKGAdviceBoardWidget::applyRecommended()
+{
+    m_inapplyall = true;
+    int nb = m_recommendedActions.count();
+    for (int i = 0; i < nb; ++i) {
+        m_recommendedActions[i]->trigger();
+    }
+    m_inapplyall = false;
+}
+
 void SKGAdviceBoardWidget::activateAllAdvice()
 {
     SKGError err;
