@@ -46,8 +46,10 @@
 SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
     : SKGTabPage(iDocument)
 {
-    SKGTRACEIN(1, "SKGMonthlyPluginWidget::SKGMonthlyPluginWidget");
-    if (!iDocument) return;
+    SKGTRACEINFUNC(1);
+    if (!iDocument) {
+        return;
+    }
 
     ui.setupUi(this);
     ui.kDeleteTemplate->hide();
@@ -75,12 +77,12 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
 
 SKGMonthlyPluginWidget::~SKGMonthlyPluginWidget()
 {
-    SKGTRACEIN(1, "SKGMonthlyPluginWidget::~SKGMonthlyPluginWidget");
+    SKGTRACEINFUNC(1);
 }
 
 QString SKGMonthlyPluginWidget::getState()
 {
-    SKGTRACEIN(10, "SKGMonthlyPluginWidget::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -95,17 +97,21 @@ QString SKGMonthlyPluginWidget::getState()
 
 void SKGMonthlyPluginWidget::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGMonthlyPluginWidget::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
     // Set state
     QString month = root.attribute("month");
-    if (!month.isEmpty()) ui.kMonth->setText(month);
+    if (!month.isEmpty()) {
+        ui.kMonth->setText(month);
+    }
 
     QString webS = root.attribute("web");
-    if (!webS.isEmpty()) ui.kWebView->setState(webS);
+    if (!webS.isEmpty()) {
+        ui.kWebView->setState(webS);
+    }
 
     QString templat = root.attribute("template");
     if (!templat.isEmpty()) {
@@ -128,7 +134,7 @@ QWidget* SKGMonthlyPluginWidget::mainWidget()
 
 void SKGMonthlyPluginWidget::fillTemplateList()
 {
-    disconnect(ui.kTemplate, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
+    disconnect(ui.kTemplate, SIGNAL(currentIndexChanged(int)), this, SLOT(onPeriodChanged()));
     // Get previous selected item
     QString current = ui.kTemplate->text();
 
@@ -137,12 +143,16 @@ void SKGMonthlyPluginWidget::fillTemplateList()
     foreach(const QString & file, KStandardDirs().findAllResources("data", KGlobal::mainComponent().aboutData()->appName() % "/html/*.txt")) {
         QFileInfo f(file);
         QString file2 = f.completeBaseName();
-        if (!ui.kTemplate->contains(file2) && file2 != "main") ui.kTemplate->addItem(file2, file);
+        if (!ui.kTemplate->contains(file2) && file2 != "main") {
+            ui.kTemplate->addItem(file2, file);
+        }
     }
 
     // Set previous selected itemData
-    if (!current.isEmpty() && ui.kTemplate->contains(current)) ui.kTemplate->setCurrentItem(current);
-    connect(ui.kTemplate, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()), Qt::QueuedConnection);
+    if (!current.isEmpty() && ui.kTemplate->contains(current)) {
+        ui.kTemplate->setCurrentItem(current);
+    }
+    connect(ui.kTemplate, SIGNAL(currentIndexChanged(int)), this, SLOT(onPeriodChanged()), Qt::QueuedConnection);
 }
 
 void SKGMonthlyPluginWidget::onAddTemplate()
@@ -156,8 +166,9 @@ void SKGMonthlyPluginWidget::onAddTemplate()
         if (!templates.contains(templatFileName)) {
             // Create the new template
             QString source = KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default.txt");
-            if (SKGServices::upload(source, templatFileName)) err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
-            else {
+            if (SKGServices::upload(source, templatFileName)) {
+                err.setReturnCode(ERR_FAIL).setMessage(i18nc("An error message", "Impossible to copy file from '%1' to '%2'", source, templatFileName));
+            } else {
                 fillTemplateList();
             }
         }
@@ -182,7 +193,9 @@ void SKGMonthlyPluginWidget::onDeleteTemplate()
 
         // Delete the file
         QFile file(templatFileName);
-        if (!file.remove()) err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", templatFileName));
+        if (!file.remove()) {
+            err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Deletion of '%1' failed", templatFileName));
+        }
 
         IFOK(err) ui.kTemplate->removeItem(ui.kTemplate->findText(templat));
 
@@ -202,7 +215,7 @@ void SKGMonthlyPluginWidget::onTemplateChanged()
 
 void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-    SKGTRACEIN(1, "SKGMonthlyPluginWidget::dataModified");
+    SKGTRACEINFUNC(1);
     Q_UNUSED(iIdTransaction);
 
     QSqlDatabase* db = getDocument()->getDatabase();
@@ -210,32 +223,74 @@ void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTran
     // TODO(Stephane MANKOWSKI): v_operation_display must be generic
     if (db != NULL && (iTableName == "v_operation_display" || iTableName.isEmpty())) {
         // Fill combo
-        disconnect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
+        disconnect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onPeriodChanged()));
 
         QStringList list;
-        getDocument()->getDistinctValues("v_operation_display", "d_DATEMONTH", "d_date<=CURRENT_DATE", list);
-        list.removeOne(QDate::currentDate().toString("yyyy-MM"));
-        qSort(list.begin(), list.end(), qGreater<QString>());
+        getDocument()->getDistinctValues("v_operation_display", "MIN(d_DATEMONTH)", "d_date<=CURRENT_DATE", list);
+        if (list.count()) {
+            if (!list[0].isEmpty()) {
+                QDate c = SKGServices::periodToDate(list[0]);
+                c = c.addDays(1 - c.day());
+
+                QDate today = QDate::currentDate();
+                QString smonth = SKGServices::dateToPeriod(today, "M");
+                QString squater = SKGServices::dateToPeriod(today, "Q");
+                QString ssemester = SKGServices::dateToPeriod(today, "S");
+                QString syear = SKGServices::dateToPeriod(today, "Y");
+
+                // Build the list
+                list.clear();
+                do {
+                    QString cmonth = SKGServices::dateToPeriod(c, "M");
+                    QString cquater = SKGServices::dateToPeriod(c, "Q");
+                    QString csemester = SKGServices::dateToPeriod(c, "S");
+                    QString cyear = SKGServices::dateToPeriod(c, "Y");
+                    if (cmonth != smonth) {
+                        list.insert(0, cmonth);
+                    }
+                    if (c.month() % 3 == 0 && cquater != squater) {
+                        list.insert(0, cquater);
+                    }
+                    if (c.month() % 6 == 0 && csemester != ssemester) {
+                        list.insert(0, csemester);
+                    }
+                    if (c.month() == 12 && cyear != syear) {
+                        list.insert(0, cyear);
+                    }
+
+                    c = c.addMonths(1);
+
+                    if (cmonth == smonth || c >= today) {
+                        break;
+                    }
+                } while (true);
+            }
+        }
 
         QString month = ui.kMonth->text();
         ui.kMonth->clear();
         ui.kMonth->addItem(i18nc("The month before the current month", "Last month"));
         ui.kMonth->addItems(list);
-        if (!month.isEmpty()) ui.kMonth->setText(month);
+        if (!month.isEmpty()) {
+            ui.kMonth->setText(month);
+        }
         ui.kRefresh->setEnabled(list.count() > 0);
-        connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()), Qt::QueuedConnection);
+        connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onPeriodChanged()), Qt::QueuedConnection);
 
-        onMonthChanged();
+        onPeriodChanged();
     }
 }
 
-QString SKGMonthlyPluginWidget::getMonth()
+QString SKGMonthlyPluginWidget::getPeriod()
 {
     QString month;
     if (month.isEmpty()) {
         if (ui.kMonth->currentIndex() == 0) {
             // Last month
-            if (ui.kMonth->count() > 1) month = ui.kMonth->itemText(1);
+            if (ui.kMonth->count() > 1) {
+                QDate today = QDate::currentDate();
+                month = today.addDays(1 - today.day()).addMonths(-1).toString("yyyy-MM");
+            }
         } else {
             // Specific month
             month = ui.kMonth->text();
@@ -244,10 +299,10 @@ QString SKGMonthlyPluginWidget::getMonth()
     return month;
 }
 
-void SKGMonthlyPluginWidget::onMonthChanged()
+void SKGMonthlyPluginWidget::onPeriodChanged()
 {
-    SKGTRACEIN(1, "SKGMonthlyPluginWidget::onMonthChanged");
-    QString month = getMonth();
+    SKGTRACEINFUNC(1);
+    QString month = getPeriod();
     if (!month.isEmpty()) {
         // Display report
         QString htmlReport = getDocument()->getParameter("SKG_MONTHLY_REPORT_" % month);
@@ -284,7 +339,9 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
     KZip zip(zipFileName);
     if (zip.open(QIODevice::WriteOnly)) {
         zip.addLocalFile(templatFileName, templat % ".txt");
-        if (QFile(templatHFileName).exists()) zip.addLocalFile(templatHFileName, templat % ".html");
+        if (QFile(templatHFileName).exists()) {
+            zip.addLocalFile(templatHFileName, templat % ".html");
+        }
         zip.close();
 
         // Create screen shots
@@ -325,14 +382,14 @@ QString SKGMonthlyPluginWidget::getReport()
 {
     QString html;
     SKGError err;
-    SKGTRACEINRC(10, "SKGMonthlyPluginWidget::getReport", err);
+    SKGTRACEINFUNCRC(10, err);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-    // Get month
-    if (!getMonth().isEmpty()) {
+    // Get period
+    if (!getPeriod().isEmpty()) {
         SKGReport* rep = getDocument()->getReport();
         if (rep) {
-            rep->setMonth(getMonth());
+            rep->setPeriod(getPeriod());
             err = rep->getReportFromTemplate(rep, ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString(), html);
 
             delete rep;
