@@ -275,7 +275,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
                     for (int j = 1; j < nb2; ++j) {
                         // id;date;format;label;idparent;price;currency;deadline;startdate;finishdate
                         QStringList fields = SKGServices::splitCSVLine(m_bills.at(j));
-                        if (!importedBills.contains(fields.at(0)) && fields.count() > 3) {
+                        if (fields.count() && fields.count() > 3 && !importedBills.contains(fields.at(0))) {
                             QStringList ids = SKGServices::splitCSVLine(fields.at(0), '@');
                             if (ids.count() == 2) {
                                 QString backend = ids.at(1);
