@@ -416,29 +416,29 @@ QWidget* SKGOperationPlugin::getPreferenceWidget()
     SKGTRACEINFUNC(10);
     QWidget* w = new QWidget();
     ui.setupUi(w);
-    
+
     // Set labels
     ui.kPayeeFakeLbl->setText(i18n("%1:", m_currentBankDocument->getDisplay("t_payee")));
     ui.kCategoryFakeLbl->setText(i18n("%1:", m_currentBankDocument->getDisplay("t_CATEGORY")));
-    ui.kCommentFakeLbl->setText(i18n("%1:", m_currentBankDocument->getDisplay("t_comment")));  
-    
+    ui.kCommentFakeLbl->setText(i18n("%1:", m_currentBankDocument->getDisplay("t_comment")));
+
     ui.kCategoryCommissionLbl->setText(ui.kCategoryFakeLbl->text());
-    ui.kCommentCommissionLbl->setText(ui.kCommentFakeLbl->text());      
-    
+    ui.kCommentCommissionLbl->setText(ui.kCommentFakeLbl->text());
+
     ui.kCategoryTaxLbl->setText(ui.kCategoryFakeLbl->text());
-    ui.kCommentTaxLbl->setText(ui.kCommentFakeLbl->text());      
+    ui.kCommentTaxLbl->setText(ui.kCommentFakeLbl->text());
 
     // Fill combo boxes and auto complession
     SKGMainPanel::fillWithDistinctValue(ui.kcfg_categoryFakeOperation, m_currentBankDocument, "category", "t_fullname", "");
     SKGMainPanel::fillWithDistinctValue(ui.kcfg_payeeFakeOperation, m_currentBankDocument, "payee", "t_name", "");
     SKGMainPanel::fillWithDistinctValue(ui.kcfg_commentFakeOperation, m_currentBankDocument, "v_operation_all_comment", "t_comment", "", true);
-    
+
     SKGMainPanel::fillWithDistinctValue(ui.kcfg_categoryCommissionOperation, m_currentBankDocument, "category", "t_fullname", "");
-    SKGMainPanel::fillWithDistinctValue(ui.kcfg_commentCommissionOperation, m_currentBankDocument, "v_operation_all_comment", "t_comment", "", true);    
+    SKGMainPanel::fillWithDistinctValue(ui.kcfg_commentCommissionOperation, m_currentBankDocument, "v_operation_all_comment", "t_comment", "", true);
 
     SKGMainPanel::fillWithDistinctValue(ui.kcfg_categoryTaxOperation, m_currentBankDocument, "category", "t_fullname", "");
-    SKGMainPanel::fillWithDistinctValue(ui.kcfg_commentTaxOperation, m_currentBankDocument, "v_operation_all_comment", "t_comment", "", true);    
-    
+    SKGMainPanel::fillWithDistinctValue(ui.kcfg_commentTaxOperation, m_currentBankDocument, "v_operation_all_comment", "t_comment", "", true);
+
     return w;
 }
 
@@ -883,13 +883,13 @@ void SKGOperationPlugin::onOpenOperations()
                 view = "v_suboperation_consolidated";
             } else if (table == "operation") {
                 // Build whereclause and title
-		titleOpen = i18nc("Noun, a list of items", "Sub operations grouped or split of:");
-		view = "v_suboperation_consolidated";
+                titleOpen = i18nc("Noun, a list of items", "Sub operations grouped or split of:");
+                view = "v_suboperation_consolidated";
 
                 for (int i = 0; i < nb; ++i) {
                     SKGOperationObject tmp(selection.at(i));
                     if (i) {
-                        wc += ',';
+                        wc += " OR ";
                         titleOpen += ',';
                     }
 
@@ -909,13 +909,13 @@ void SKGOperationPlugin::onOpenOperations()
                 iconOpen = "view-financial-list";
             } else if (table == "suboperation") {
                 // Build whereclause and title
-		titleOpen = i18nc("Noun, a list of items", "Operations grouped with:");
-		view = "v_operation_display_all";
+                titleOpen = i18nc("Noun, a list of items", "Operations grouped with:");
+                view = "v_operation_display_all";
 
                 for (int i = 0; i < nb; ++i) {
                     SKGSubOperationObject tmp(selection.at(i).getDocument(), selection.at(i).getID());
-		    SKGOperationObject op;
-		    tmp.getParentOperation(op);
+                    SKGOperationObject op;
+                    tmp.getParentOperation(op);
                     if (i) {
                         wc += ',';
                         titleOpen += ',';
@@ -990,14 +990,14 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(7);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Duplicate number %1 in account '%2'", number, account));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Your account '%1' contains more than one operation with number %2.The operation number should be unique (check number, transaction reference...)", account, number));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title=i18nc("Advice on making the best (action)", "Edit operations with duplicate number");
-	      a.IconName="skg_open";
-	      a.IsRecommended=false;
-	      autoCorrections.push_back(a);
-	    }
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = i18nc("Advice on making the best (action)", "Edit operations with duplicate number");
+                a.IconName = "skg_open";
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -1018,14 +1018,14 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(9);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many operations of '%1' not reconciliated", account));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Don't forget to reconciliate your accounts. By doing so, you acknowledge that your bank has indeed processed these operations on your account. This is how you enforce compliance with your bank's statements. See online help for more details"));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title=i18nc("Advice on making the best (action)", "Open account '%1' for reconciliation", account);
-	      a.IconName="skg_open";
-	      a.IsRecommended=false;
-	      autoCorrections.push_back(a);
-	    }
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = i18nc("Advice on making the best (action)", "Open account '%1' for reconciliation", account);
+                a.IconName = "skg_open";
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -1124,19 +1124,19 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some operations are in groups with only one operation"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "When a transfer is created and when only one part of this transfer is removed, the second part is in a group of only one operation. This makes no sense."));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://view_open_operation_in_group_of_one";
-	      a.IsRecommended=false;
-	      autoCorrections.push_back(a);
-	    }
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://clean_remove_group_with_one_operation";
-	      a.IsRecommended=true;
-	      autoCorrections.push_back(a);
-	    }	    
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://view_open_operation_in_group_of_one";
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://clean_remove_group_with_one_operation";
+                a.IsRecommended = true;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -1152,19 +1152,19 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some simple operations don't have their comments aligned"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The comment of the operation is not aligned with the comment of the suboperation."));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://view_open_operation_with_comment_not_aligned";
-	      a.IsRecommended=false;
-	      autoCorrections.push_back(a);
-	    }
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://clean_align_comment";
-	      a.IsRecommended=true;
-	      autoCorrections.push_back(a);
-	    }	    
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://view_open_operation_with_comment_not_aligned";
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://clean_align_comment";
+                a.IsRecommended = true;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -1180,19 +1180,19 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some simple operations don't have their dates aligned"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The date of the operation is not aligned with the date of the suboperation."));
-	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://view_open_operation_with_date_not_aligned";
-	      a.IsRecommended=false;
-	      autoCorrections.push_back(a);
-	    }
-	    {
-	      SKGAdvice::SKGAdviceAction a;
-	      a.Title="skg://clean_align_date";
-	      a.IsRecommended=true;
-	      autoCorrections.push_back(a);
-	    }	    
+            QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://view_open_operation_with_date_not_aligned";
+                a.IsRecommended = false;
+                autoCorrections.push_back(a);
+            }
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = "skg://clean_align_date";
+                a.IsRecommended = true;
+                autoCorrections.push_back(a);
+            }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
