@@ -112,7 +112,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
 
     // Adding properties
     QStringList properties;
-    iDocument->getDistinctValues("parameters", "t_name", "t_uuid_parent like '%-operation' AND t_name NOT LIKE 'SKG_%'", properties);
+    iDocument->getDistinctValues("parameters", "t_name", "(t_uuid_parent like '%-operation' OR t_uuid_parent like '%-suboperation') AND t_name NOT LIKE 'SKG_%'", properties);
     int nb = properties.count();
     for (int i = 0; i < nb; ++i) {
         attributeForQuery.push_back("p_" % properties.at(i));
