@@ -64,7 +64,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
     // Build list of attributes
     if (m_document) {
         SKGQueryDelegate* delegate = new SKGQueryDelegate(ui.kList, m_document, m_updateMode, iListAttribute);
-        connect(delegate, SIGNAL(closeEditor(QWidget*,QAbstractItemDelegate::EndEditHint)), this, SLOT(onCloseEditor()));
+        connect(delegate, SIGNAL(commitData(QWidget*)), this, SLOT(onCloseEditor()), Qt::QueuedConnection);
 
         ui.kList->setItemDelegate(delegate);
 
