@@ -378,7 +378,7 @@ SKGError SKGAccountObject::getUnit(SKGUnitObject& oUnit) const
 {
     // Get initial amount
     SKGStringListList listTmp;
-    SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_operation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
+    SKGError err = getDocument()->executeSelectSqliteOrder("SELECT t_UNIT FROM  v_suboperation_consolidated  WHERE d_date='0000-00-00' AND rd_account_id=" % SKGServices::intToString(getID()), listTmp);
     IFOK(err) {
         // Is initial amount existing ?
         if (listTmp.count() > 1) {
