@@ -67,7 +67,8 @@ public:
      */
     enum ActionType {SEARCH,
                      UPDATE,
-                     ALARM
+                     ALARM,
+                     APPLYTEMPLATE
                     };
     /**
      * Constructor
@@ -108,7 +109,7 @@ public:
     /**
      * Set the XML for the search definition
      * @param iXml the XML search definition
-     * @code exemple:
+     * @code example:
      * <!DOCTYPE SKGML>
      *   <element> <!--OR-->
      *     <element>  <!--AND-->
@@ -130,7 +131,7 @@ public:
     /**
      * Set the XML for the action definition
      * @param iXml the XML action definition
-     * @code exemple for an update action:
+     * @code example for an update action:
      * <!DOCTYPE SKGML>
      *   <element> <!--OR-->
      *     <element>  <!--AND-->
@@ -138,7 +139,7 @@ public:
      *     </element>
      *   </element>
      * @endcode
-     * @code exemple for an alarm action:
+     * @code example for an alarm action:
      * <!DOCTYPE SKGML>
      *   <element> <!--OR-->
      *     <element>  <!--AND-->
@@ -146,6 +147,14 @@ public:
      *     </element>
      *   </element>
      * @endcode
+     * @code example to apply a template:
+     * <!DOCTYPE SKGML>
+     *   <element> <!--OR-->
+     *     <element>  <!--AND-->
+     *       <element attribute="id" operator="APPLYTEMPLATE(#V1#)" value="123" value2="The template name"/>
+     *     </element>
+     *   </element>
+     * @endcode*
      * @return an object managing the error
      *   @see SKGError
      */
