@@ -54,7 +54,7 @@ namespace KPIM
   @author David Jarvie <software@astrojar.org.uk>
   @author Tobias Koenig <tokoe@kde.org>
 */
-class SKGBASEGUI_EXPORT KDateEdit : public QComboBox //krazy:exclude=qclasses
+class SKGBASEGUI_EXPORT KDateEdit : public QComboBox // krazy:exclude=qclasses
 {
     Q_OBJECT
     Q_PROPERTY(QDate date READ date WRITE setDate)
@@ -125,11 +125,11 @@ protected:
       validation on the date value before it is set. Derived classes should
       return true if QDate::isValid(@p date) returns false.
 
-      @param date The new date to set.
+      @param iDate The new date to set.
       @return True if the date was set, false if it was considered invalid and
               remains unchanged.
      */
-    virtual bool assignDate(const QDate& date);
+    virtual bool assignDate(const QDate& iDate);
 
     /**
       Fills the keyword map. Reimplement it if you want additional keywords.
