@@ -76,7 +76,9 @@ void SKGComboBox::setSubstringCompletionMode(bool iMode)
 {
     m_substringCompletionMode = iMode;
     SKGLineEdit* line = qobject_cast<SKGLineEdit*>(lineEdit());
-    if (line) line->setSubstringCompletionMode(iMode);
+    if (line) {
+        line->setSubstringCompletionMode(iMode);
+    }
 }
 
 #include "skgcombobox.moc"
