@@ -179,8 +179,9 @@ void SKGFilteredTableView::setFilter(const KIcon& iIcon, const QString& iText, c
     if (m_objectModel && !iWhereClause.isEmpty()) {
         getShowWidget()->setEnabled(false);
 
-        ui.kTitle->setComment("<html><body><b>" % SKGServices::stringToHtml(iText) % "</b></body></html>");
-        ui.kTitle->show();
+        QFontMetrics fm(fontMetrics());
+        ui.kTitle->setComment("<html><body><b>" % SKGServices::stringToHtml(fm.elidedText(iText, Qt::ElideMiddle, 2000)) % "</b></body></html>");
+        ui.kTitle->setToolTip(iText);
         ui.kResetInternalFilter->show();
 
         ui.kTitle->setPixmap(KIcon(iIcon).pixmap(22, 22), KTitleWidget::ImageLeft);
