@@ -359,6 +359,13 @@ protected:
      */
     QVariant m_fontNegativeColor;
 
+    /**
+     * Get the string of an amount
+     * @param iValue the value
+     * @return the string
+     */
+    virtual QString formatMoney(double iValue) const;
+
 private Q_SLOTS:
     void pageChanged();
 
