@@ -30,6 +30,12 @@
 class SKGBASEGUI_EXPORT SKGProgressBar : public QProgressBar
 {
     Q_OBJECT
+
+    /**
+     * Property value
+     */
+    Q_PROPERTY(int value READ value WRITE setValue)
+
 public:
     /**
      * Constructor
