@@ -107,12 +107,16 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
                 d->m_insubsort = false;
                 return test;
             }
-            // Compare on previous column
-            if (!d->m_insubsort && d->m_previous != -1) {
-                d->m_insubsort = true;
-                bool test = QSortFilterProxyModel::lessThan(model->index(left.row(), d->m_previous), model->index(right.row(), d->m_previous));
-                d->m_insubsort = false;
-                return test;
+            if (leftData.userType() != QVariant::Date &&
+                leftData.userType() != QVariant::DateTime &&
+                leftData.userType() != QVariant::Time) {
+                // Compare on previous column
+                if (!d->m_insubsort && d->m_previous != -1) {
+                    d->m_insubsort = true;
+                    bool test = QSortFilterProxyModel::lessThan(model->index(left.row(), d->m_previous), model->index(right.row(), d->m_previous));
+                    d->m_insubsort = false;
+                    return test;
+                }
             }
 
             // Compare on ID for stability
@@ -121,42 +125,82 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
         } else {
             // For better performances, and avoid too many calls to QAbstractItemModel::data
             // return QSortFilterProxyModel::lessThan(left, right);
-            switch (leftData.userType()) {
-            case QVariant::Invalid:
-                return (rightData.type() != QVariant::Invalid);
-            case QVariant::Int:
-                return leftData.toInt() < rightData.toInt();
-            case QVariant::UInt:
-                return leftData.toUInt() < rightData.toUInt();
-            case QVariant::LongLong:
-                return leftData.toLongLong() < rightData.toLongLong();
-            case QVariant::ULongLong:
-                return leftData.toULongLong() < rightData.toULongLong();
-            case QMetaType::Float:
-                return leftData.toFloat() < rightData.toFloat();
-            case QVariant::Double:
-                return leftData.toDouble() < rightData.toDouble();
-            case QVariant::Char:
-                return leftData.toChar() < rightData.toChar();
-            case QVariant::Date:
-                return leftData.toDate() < rightData.toDate();
-            case QVariant::Time:
-                return leftData.toTime() < rightData.toTime();
-            case QVariant::DateTime:
-                return leftData.toDateTime() < rightData.toDateTime();
-            case QVariant::String:
-            default:
-                if (this->isSortLocaleAware()) {
-                    return leftData.toString().localeAwareCompare(rightData.toString()) < 0;
-                } else {
-                    return leftData.toString().compare(rightData.toString(), this->sortCaseSensitivity()) < 0;
-                }
-            }
+            return lessThan(leftData, rightData);
         }
     }
     return false;
 }
 
+bool SKGSortFilterProxyModel::lessThan(const QVariant& iLeftData, const QVariant& iRightData) const
+{
+    switch (iLeftData.userType()) {
+    case QVariant::Invalid:
+        return (iRightData.type() != QVariant::Invalid);
+    case QVariant::Int:
+        return iLeftData.toInt() < iRightData.toInt();
+    case QVariant::UInt:
+        return iLeftData.toUInt() < iRightData.toUInt();
+    case QVariant::LongLong:
+        return iLeftData.toLongLong() < iRightData.toLongLong();
+    case QVariant::ULongLong:
+        return iLeftData.toULongLong() < iRightData.toULongLong();
+    case QMetaType::Float:
+        return iLeftData.toFloat() < iRightData.toFloat();
+    case QVariant::Double:
+        return iLeftData.toDouble() < iRightData.toDouble();
+    case QVariant::Char:
+        return iLeftData.toChar() < iRightData.toChar();
+    case QVariant::Date:
+        return iLeftData.toDate() < iRightData.toDate();
+    case QVariant::Time:
+        return iLeftData.toTime() < iRightData.toTime();
+    case QVariant::DateTime:
+        return iLeftData.toDateTime() < iRightData.toDateTime();
+    case QVariant::String:
+    default:
+        if (this->isSortLocaleAware()) {
+            return iLeftData.toString().localeAwareCompare(iRightData.toString()) < 0;
+        } else {
+            return iLeftData.toString().compare(iRightData.toString(), this->sortCaseSensitivity()) < 0;
+        }
+    }
+}
+
+bool SKGSortFilterProxyModel::moreThan(const QVariant& iLeftData, const QVariant& iRightData) const
+{
+    switch (iLeftData.userType()) {
+    case QVariant::Invalid:
+        return (iRightData.type() != QVariant::Invalid);
+    case QVariant::Int:
+        return iLeftData.toInt() > iRightData.toInt();
+    case QVariant::UInt:
+        return iLeftData.toUInt() > iRightData.toUInt();
+    case QVariant::LongLong:
+        return iLeftData.toLongLong() > iRightData.toLongLong();
+    case QVariant::ULongLong:
+        return iLeftData.toULongLong() > iRightData.toULongLong();
+    case QMetaType::Float:
+        return iLeftData.toFloat() > iRightData.toFloat();
+    case QVariant::Double:
+        return iLeftData.toDouble() > iRightData.toDouble();
+    case QVariant::Char:
+        return iLeftData.toChar() > iRightData.toChar();
+    case QVariant::Date:
+        return iLeftData.toDate() > iRightData.toDate();
+    case QVariant::Time:
+        return iLeftData.toTime() > iRightData.toTime();
+    case QVariant::DateTime:
+        return iLeftData.toDateTime() > iRightData.toDateTime();
+    case QVariant::String:
+    default:
+        if (this->isSortLocaleAware()) {
+            return iLeftData.toString().localeAwareCompare(iRightData.toString()) < 0;
+        } else {
+            return iLeftData.toString().compare(iRightData.toString(), this->sortCaseSensitivity()) > 0;
+        }
+    }
+}
+
 bool SKGSortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
 {
     _SKGTRACEINFUNC(10);
@@ -209,6 +253,25 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
         int nbwords = iWords.count();
         for (int w = 0; output && w < nbwords; ++w) {
             QString word = iWords.at(w);
+            QString att;
+            QChar op = ':';
+
+            // Check if the word follows the format attribut:value
+            int pos = word.indexOf(':');
+            int pos2 = word.indexOf('<');
+            int pos3 = word.indexOf('>');
+            if (pos2 != -1 && (pos2 < pos || pos == -1)) {
+                pos = pos2;
+            }
+            if (pos3 != -1 && (pos3 < pos || pos == -1)) {
+                pos = pos3;
+            }
+
+            if (pos != -1) {
+                att = word.left(pos);
+                op = word[pos];
+                word = word.right(word.count() - pos - 1);
+            }
 
             // Is this word validated by at least one column ?
             output = false;
@@ -216,9 +279,22 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
             for (int i = 0; !output && i < nbcol; ++i) {
                 QModelIndex index0 = model->index(source_row, i, source_parent);
                 if (index0.isValid()) {
-                    output = model->data(index0).toString().contains(word , Qt::CaseInsensitive);
-                    if (!output) {
-                        output = model->data(index0, Qt::UserRole).toString().contains(word , Qt::CaseInsensitive);
+                    // Check if the header validates the attribut
+                    if (att.isEmpty() || model->headerData(i, Qt::Horizontal).toString().startsWith(att, Qt::CaseInsensitive)) {
+
+                        // Check if the value validate the attribute
+                        if (op == ':') {
+                            output = model->data(index0).toString().contains(word , Qt::CaseInsensitive);
+                            if (!output) {
+                                output = model->data(index0, Qt::UserRole).toString().contains(word , Qt::CaseInsensitive);
+                            }
+                        } else if (op == '<') {
+                            QVariant var = model->data(index0, Qt::UserRole);
+                            output = lessThan(var, QVariant(word));
+                        } else if (op == '>') {
+                            QVariant var = model->data(index0, Qt::UserRole);
+                            output = moreThan(var, QVariant(word));
+                        }
                     }
                 }
             }
