@@ -364,6 +364,15 @@ void SKGTreeView::refreshExpandCollapse()
     }
 }
 
+void SKGTreeView::respanFirstColumns()
+{
+    // Span groups
+    int nbRow = m_model->rowCount();
+    for (int row = 0; row < nbRow; ++row) {
+        this -> setFirstColumnSpanned(row, QModelIndex(), !m_groupby.isEmpty());
+    }
+}
+
 void SKGTreeView::onRangeChanged()
 {
     QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
@@ -413,6 +422,8 @@ void SKGTreeView::resizeColumnsToContentsDelayed()
 void SKGTreeView::resizeColumnsToContents()
 {
     SKGTRACEINFUNC(10);
+    respanFirstColumns();
+
     int nb = header()->count();
     for (int i = nb - 1; i >= 0; --i) {
         resizeColumnToContents(i);
