@@ -60,7 +60,7 @@ SKGWebView::~SKGWebView()
 
 QString SKGWebView::getState()
 {
-    SKGTRACEIN(10, "SKGWebView::getState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
@@ -70,12 +70,14 @@ QString SKGWebView::getState()
 
 void SKGWebView::setState(const QString& iState)
 {
-    SKGTRACEIN(10, "SKGWebView::setState");
+    SKGTRACEINFUNC(10);
     QDomDocument doc("SKGML");
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
     QString zoomPosition = root.attribute("zoomFactor");
-    if (zoomPosition.isEmpty()) zoomPosition = '0';
+    if (zoomPosition.isEmpty()) {
+        zoomPosition = '0';
+    }
     double z = qPow(10, (static_cast<qreal>(SKGServices::stringToInt(zoomPosition)) / 30.0));
     setZoomFactor(z);
     emit zoomChanged(z);
@@ -104,7 +106,7 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 
 bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    SKGTRACEIN(10, "SKGWebView::eventFilter");
+    SKGTRACEINFUNC(10);
     if (iEvent && iEvent->type() == QEvent::Wheel) {
         QWheelEvent* e = static_cast<QWheelEvent*>(iEvent);
         if (e) {
@@ -127,7 +129,7 @@ bool SKGWebView::eventFilter(QObject* iObject, QEvent* iEvent)
 
 void SKGWebView::onZoomIn()
 {
-    _SKGTRACEIN(10, "SKGWebView::onZoomIn");
+    _SKGTRACEINFUNC(10);
     int z = qMin(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) + 1, 10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
 
@@ -136,7 +138,7 @@ void SKGWebView::onZoomIn()
 
 void SKGWebView::onZoomOut()
 {
-    _SKGTRACEIN(10, "SKGWebView::onZoomOut");
+    _SKGTRACEINFUNC(10);
     int z = qMax(static_cast<int>(qRound(30.0 * log10(zoomFactor()))) - 1, -10);
     setZoomFactor(qPow(10, static_cast<qreal>(z) / 30.0));
 
@@ -145,7 +147,7 @@ void SKGWebView::onZoomOut()
 
 void SKGWebView::onZoomOriginal()
 {
-    _SKGTRACEIN(10, "SKGWebView::onZoomOriginal");
+    _SKGTRACEINFUNC(10);
     setZoomFactor(0);
 
     emit zoomChanged(0);
@@ -163,9 +165,7 @@ void SKGWebView::exportInFile(const QString& iFileName)
     } else if (extension == "PDF") {
         QPrinter printer;
         printer.setOutputFileName(iFileName);
-        QPainter painter(&printer);
-        this->render(&painter);
-        painter.end();
+        print(&printer);
     } else if (extension == "HTML" || extension == "HTM") {
         KSaveFile file(iFileName);
         if (file.open()) {
@@ -187,9 +187,11 @@ void SKGWebView::exportInFile(const QString& iFileName)
 
 void SKGWebView::onExport()
 {
-    _SKGTRACEIN(10, "SKGWebView::onExport");
+    _SKGTRACEINFUNC(10);
     QString fileName = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "application/pdf text/html application/vnd.oasis.opendocument.text image/png image/jpeg image/gif image/tiff", this);
-    if (fileName.isEmpty()) return;
+    if (fileName.isEmpty()) {
+        return;
+    }
 
     exportInFile(fileName);
 
@@ -198,7 +200,7 @@ void SKGWebView::onExport()
 
 void SKGWebView::onPrintPreview()
 {
-    SKGTRACEIN(10, "SKGWebView::onPrintPreview");
+    SKGTRACEINFUNC(10);
     QPointer<QPrintPreviewDialog> dialog = new QPrintPreviewDialog(this);
     connect(dialog, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
     dialog->exec();
@@ -207,7 +209,7 @@ void SKGWebView::onPrintPreview()
 
 void SKGWebView::onPrint()
 {
-    _SKGTRACEIN(10, "SKGWebView::onPrint");
+    _SKGTRACEINFUNC(10);
     QPrinter printer;
     QPointer<QPrintDialog> dialog = new QPrintDialog(&printer, this);
     if (dialog->exec() == QDialog::Accepted) {
